==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>ཞིབ་བཤེར་བྱེད་བཞིན་པ། ཚར་གྲབས་ཡོད། ཁྱེད་ཀྱིས་ངང་རྒྱུད་རིང་པོས་སྒུག་པར་ཐུགས་རྗེ་ཆེ།</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>གྲ་སྒྲིག་བྱེད་བཞིན་པ།</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>ནོར་འཁྲུལ་འགའ་ཤེས་རྟོགས་བྱུང་།</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>ཅོག་ངོས་ལ་འཛུལ་བ།</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>དགའ་བསུ་ཞུ། རྒྱུད་ཁོངས་རིམ་སྤོར་ལེགས་གྲུབ་བྱུང་སོང་།</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>མིག་སྔའི་པར་གཞི།</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>ཉིན་ཐོར་ལྟ་བ།</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>གསར་དུ་བསྒྱུར་ཟིན།</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>ཁྱེད་ཀྱི་གློག་ཀླད་བསྐྱར་དུ་འགོ་སློང་གྲབས་ཡོད། %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>ཁྱེད་ཀྱི་གློག་ཀླད་སྒོ་རྒྱག་གྲབས་ཡོད། %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>ཉིན་ཐོ་བསྡུ་བ།</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>གསར་སྒྱུར་མི་ཐུབ་པ། </translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>རྒྱུ་མཚན་མ་ཤེས་པའི་ནོར་འཁྲུལ།</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>གྲབས་ཉར་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>རྒྱུད་ཁོངས་གྲབས་ཉར་བྱེད་ཐབས་བྲལ། མུ་མཐུད་རིམ་པ་སྤར་ཚེ་རྒྱུད་ཁོངས་ཕྱིར་ལོག་བྱེད་ཐབས་བྲལ་སྲིད། </translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>སྡུད་སྡེར་གྱི་ཤོང་ཚད་མི་འདང་བས་དུས་ཐོག་ཏུ་གཙང་སེལ་བྱས་རྗེས་གསར་སྒྱུར་བྱོས།</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>གྲབས་ཉར་ཞབས་ཞུ་འགོ་སློང་ཐབས་བྲལ་བས། ཞིབ་བཤེར་བྱས་རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱོས།</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>གསར་སྒྱུར་ཞབས་ཞུ་འགོ་སློང་ཐབས་བྲལ་བས། ཞིབ་བཤེར་བྱས་རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱོས།</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>རྟེན་གཞི་ནོར་བ།</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>dpkgནོར་བ།</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>ཡང་བསྐྱར་གྲབས་ཉར།</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>གསར་སྒྱུར་མི་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>མུ་མཐུད་གསར་སྒྱུར།</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>བསྐྱར་སློང་།</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>ཁ་བརྒྱབ།</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>ཅོག་ངོས་ལ་འཛུལ་བ།</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>གསར་དུ་བསྒྱུར་རྩིས་བྱེད་བཞིན་པ།</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>གསར་དུ་སྒྱུར་སྐབས་བཙན་ཤེད་ཀྱིས་སྒོ་རྒྱག་པའམ་གློག་གསོད་པ་བྱེད་མི་རུང་། དེ་མིན་ན་རྒྱུད་ཁོངས་འཕྲོ་བརླག་ཐེབས་སྲིད།</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.31.tar.xz: BUILD/src/dde-update/translations/dde-update_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>ཞིབ་བཤེར་བྱེད་བཞིན་པ། ཚར་གྲབས་ཡོད། ཁྱེད་ཀྱིས་ངང་རྒྱུད་རིང་པོས་སྒུག་པར་ཐུགས་རྗེ་ཆེ།</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>གྲ་སྒྲིག་བྱེད་བཞིན་པ།</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>ནོར་འཁྲུལ་འགའ་ཤེས་རྟོགས་བྱུང་།</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>ཅོག་ངོས་ལ་འཛུལ་བ།</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>དགའ་བསུ་ཞུ། རྒྱུད་ཁོངས་རིམ་སྤོར་ལེགས་གྲུབ་བྱུང་སོང་།</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>མིག་སྔའི་པར་གཞི།</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>གསར་དུ་བསྒྱུར་ཟིན།</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>ཁྱེད་ཀྱི་གློག་ཀླད་བསྐྱར་དུ་འགོ་སློང་གྲབས་ཡོད། %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>ཁྱེད་ཀྱི་གློག་ཀླད་སྒོ་རྒྱག་གྲབས་ཡོད། %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>གསར་སྒྱུར་མི་ཐུབ་པ། </translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>རྒྱུ་མཚན་མ་ཤེས་པའི་ནོར་འཁྲུལ།</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>གྲབས་ཉར་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>རྒྱུད་ཁོངས་གྲབས་ཉར་བྱེད་ཐབས་བྲལ། མུ་མཐུད་རིམ་པ་སྤར་ཚེ་རྒྱུད་ཁོངས་ཕྱིར་ལོག་བྱེད་ཐབས་བྲལ་སྲིད། </translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>སྡུད་སྡེར་གྱི་ཤོང་ཚད་མི་འདང་བས་དུས་ཐོག་ཏུ་གཙང་སེལ་བྱས་རྗེས་གསར་སྒྱུར་བྱོས།</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>གྲབས་ཉར་ཞབས་ཞུ་འགོ་སློང་ཐབས་བྲལ་བས། ཞིབ་བཤེར་བྱས་རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱོས།</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>གསར་སྒྱུར་ཞབས་ཞུ་འགོ་སློང་ཐབས་བྲལ་བས། ཞིབ་བཤེར་བྱས་རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱོས།</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>རྟེན་གཞི་ནོར་བ།</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>dpkgནོར་བ།</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>ཡང་བསྐྱར་གྲབས་ཉར།</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>གསར་སྒྱུར་མི་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>མུ་མཐུད་གསར་སྒྱུར།</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>བསྐྱར་སློང་།</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>ཁ་བརྒྱབ།</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>ཅོག་ངོས་ལ་འཛུལ་བ།</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>གསར་དུ་བསྒྱུར་རྩིས་བྱེད་བཞིན་པ།</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>གསར་དུ་སྒྱུར་སྐབས་བཙན་ཤེད་ཀྱིས་སྒོ་རྒྱག་པའམ་གློག་གསོད་པ་བྱེད་མི་རུང་། དེ་མིན་ན་རྒྱུད་ཁོངས་འཕྲོ་བརླག་ཐེབས་སྲིད།</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
